/*!
 * Copyright (c) 2021, 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */

import jQuery from 'jquery';
import templateLoading from './templates/loading-icon.mustache';
import template from "./templates/logo-list.mustache";
import { getProjectParticipatingOrganizations } from '../api/eclipsefdn.membership';

const EclipseFdnParticipatingOrganizations = (async function ($, document) {
    const element = document.querySelector('.eclipsefdn-participating-organizations');
    if (!element) return;

    element.innerHTML = templateLoading();

    const projectShortId = element.getAttribute('data-project-short-id');

    if (!projectShortId) return;

    let [participatingOrganizations] = await getProjectParticipatingOrganizations(projectShortId);

    if (!participatingOrganizations) return;

    const data = {
        items: participatingOrganizations.map(organization => ({
            id: organization.organizationId,
            name: organization.name,
            logo: organization.logos.web
        }))
    };

    element.innerHTML = template(data);
})(jQuery, document);

export default EclipseFdnParticipatingOrganizations;
